import React, { useCallback, useEffect, useMemo, useState } from 'react';
import { Image, Keyboard, Pressable, Text, TextInput, TouchableHighlight, TouchableOpacity, View } from 'react-native';
import Modal from 'react-native-modal';
import { FlashList } from '@shopify/flash-list';
import { IMAGES } from '../../assets';
import styles, { colors, height, itemHeight, width } from './styles';
const PickerComponent = _ref => {
  let {
    data,
    value,
    placeholder,
    search,
    searchPlaceholder,
    disable,
    onChange,
    containerStyle,
    containerDisableStyle,
    textStyle,
    placeholderStyle,
    inputSearchStyle
  } = _ref;
  const [keyword, setKeyword] = useState('');
  const [dataFiltered, setDataFiltered] = useState([]);
  const [isOpened, setIsOpened] = useState(false);
  const [keyboardHeight, setKeyboardHeight] = useState(0);
  const itemSelected = useMemo(() => {
    return data.find(e => e.value === value);
  }, [data, value]);
  useEffect(() => {
    const keyboardOpened = Keyboard.addListener('keyboardDidShow', e => {
      setKeyboardHeight(e.endCoordinates.height);
    });
    const keyboardHidden = Keyboard.addListener('keyboardDidHide', () => {
      setKeyboardHeight(0);
    });
    return () => {
      keyboardOpened.remove();
      keyboardHidden.remove();
    };
  }, []);
  useEffect(() => {
    handleSearch();
  }, [keyword]);
  const handleSelectItem = item => {
    if (!disable) {
      onChange(item.value);
      setIsOpened(false);
    }
  };
  const handleSearch = () => {
    const dataFiltered = data.filter(item => {
      const labelValue = item.label.toLowerCase().trim();
      return labelValue.includes(keyword.toLowerCase().trim());
    });
    setDataFiltered(dataFiltered);
  };
  const _renderItem = useCallback(_ref2 => {
    let {
      item
    } = _ref2;
    const isSelected = item.value === value;
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TouchableHighlight, {
      activeOpacity: 0.6,
      underlayColor: colors.selected,
      onPress: () => handleSelectItem(item)
    }, /*#__PURE__*/React.createElement(Text, {
      style: [styles.textBase, styles.itemContainer, isSelected && styles.selectedTextStyle]
    }, item.label)));
  }, [value, dataFiltered]);
  const _renderModal = useCallback(() => /*#__PURE__*/React.createElement(Modal, {
    isVisible: isOpened,
    animationIn: 'fadeInUp',
    style: {
      margin: 0,
      padding: 0
    },
    statusBarTranslucent: true,
    onModalHide: () => setIsOpened(false),
    deviceWidth: width,
    deviceHeight: height
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.modalWrapper
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.modalContainer, {
      height: (data.length + 3) * itemHeight + keyboardHeight
    }]
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.modalHeaderWithSearch
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.modalHeaderWrapper
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.modalHeaderText
  }, placeholder), /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: () => setIsOpened(false),
    style: styles.modalHeaderClose
  }, /*#__PURE__*/React.createElement(Image, {
    source: IMAGES.IC_CLOSE,
    style: {
      width: 20,
      height: 20
    }
  }))), search && /*#__PURE__*/React.createElement(TextInput, {
    style: [styles.inputSearchStyle, inputSearchStyle],
    placeholder: searchPlaceholder || 'Enter keyword...',
    onChangeText: setKeyword
  })), /*#__PURE__*/React.createElement(FlashList, {
    estimatedItemSize: 100,
    data: dataFiltered,
    renderItem: _renderItem
  })))), [value, isOpened, dataFiltered, placeholder, searchPlaceholder, keyboardHeight]);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(View, {
    style: [styles.container, containerStyle, disable && {
      backgroundColor: colors.selected
    }, disable && containerDisableStyle]
  }, /*#__PURE__*/React.createElement(Pressable, {
    style: styles.btnDropdown,
    onPress: () => setIsOpened(true)
  }, itemSelected && itemSelected.label ? /*#__PURE__*/React.createElement(Text, {
    numberOfLines: 1,
    style: [styles.textBase, textStyle]
  }, itemSelected.label) : /*#__PURE__*/React.createElement(Text, {
    numberOfLines: 1,
    style: [styles.textBase, placeholderStyle]
  }, placeholder), /*#__PURE__*/React.createElement(Image, {
    source: isOpened ? IMAGES.IC_UP : IMAGES.IC_DOWN,
    style: styles.iconDropdown
  }))), _renderModal());
};
export default /*#__PURE__*/React.memo(PickerComponent);
//# sourceMappingURL=index.js.map